@@ -83,7 +83,7 @@
 #define GCONF_OSSO_SOUND_DIR "/apps/osso/sound"
 #define GCONF_MASTER_VOLUME GCONF_OSSO_SOUND_DIR "/master_volume"
 
-#define VOLUME_BEEP_DELAY 300
+//#define VOLUME_BEEP_DELAY 300
 
 
 #define GCONF_PREFIX "/apps/adv-backlight"
@@ -142,7 +142,7 @@ struct _AdvancedBacklightPluginPrivate
   gint is_770;
 
   gint notify_id;
-  guint timer_id;
+  //guint timer_id;
   struct timeval last_beep;
   gint brightness_jump;
   gint volume_jump;
@@ -158,8 +158,8 @@ struct _AdvancedBacklightPluginPrivate
   GAsyncQueue *brightness_queue;
   GString *brightness_level_string;
   GString *brightness_level_dsme_string;
-  GThread *volume_thread;
-  GAsyncQueue *volume_queue;
+  //GThread *volume_thread;
+  //GAsyncQueue *volume_queue;
   GString *volume_level_string;
 
 };
@@ -191,10 +191,11 @@ static void advanced_backlight_plugin_dsme_update_brightness_value (AdvancedBack
 static void advanced_backlight_plugin_770_update_brightness_value (AdvancedBacklightPluginPrivate *, gint);
 static void advanced_backlight_plugin_update_volume_value (AdvancedBacklightPlugin *, gint);
 static gpointer advanced_backlight_plugin_dsme_update_brightness_thread (gpointer);
-static gpointer advanced_backlight_plugin_update_volume_thread (gpointer);
+//static gpointer advanced_backlight_plugin_update_volume_thread (gpointer);
 /*static void advanced_backlight_plugin_dsme_update_brightness (AdvancedBacklightPlugin *);*/
 static void advanced_backlight_plugin_configure_applet (AdvancedBacklightPlugin * vsp);
 static void advanced_backlight_plugin_load_icons (AdvancedBacklightPlugin * vsp);
+static gboolean volume_beep (GtkWidget *w, GdkEventButton *e, AdvancedBacklightPlugin * vsp);
 
 
 static void advanced_backlight_plugin_check_init_rotation (AdvancedBacklightPlugin * vsp);
@@ -292,7 +293,7 @@ advanced_backlight_plugin_init (AdvancedBacklightPlugin * vsp)
   priv->is_770 = is_770 ();
 
   if (priv->is_770)
-	  priv->max_brightness = 123;
+	  priv->max_brightness = 126;
   else
 	  priv->max_brightness = 127;
 
@@ -348,10 +349,10 @@ advanced_backlight_plugin_finalize (GObject * object)
 
   volume_value = g_new (int, 1);
   *volume_value = priv->volume_level;
-  g_async_queue_push (priv->volume_queue, volume_value);
-  g_thread_join (priv->volume_thread);
-  g_async_queue_unref (priv->volume_queue);
-  g_async_queue_unref (priv->volume_queue);
+  //g_async_queue_push (priv->volume_queue, volume_value);
+  //g_thread_join (priv->volume_thread);
+  //g_async_queue_unref (priv->volume_queue);
+  //g_async_queue_unref (priv->volume_queue);
 
   g_string_free (priv->volume_level_string, TRUE);
 
@@ -378,8 +379,8 @@ advanced_backlight_plugin_init_threads (AdvancedBacklightPlugin * vsp)
   priv->brightness_queue = g_async_queue_new ();
   priv->brightness_thread = g_thread_create (advanced_backlight_plugin_dsme_update_brightness_thread, vsp, TRUE, NULL);
 
-  priv->volume_queue = g_async_queue_new ();
-  priv->volume_thread = g_thread_create (advanced_backlight_plugin_update_volume_thread, vsp, TRUE, NULL);
+  //priv->volume_queue = g_async_queue_new ();
+  //priv->volume_thread = g_thread_create (advanced_backlight_plugin_update_volume_thread, vsp, TRUE, NULL);
 }
 
 /*
@@ -760,18 +761,16 @@ brightness_level_changed (GtkWidget * widget, AdvancedBacklightPlugin * vsp)
   *value = priv->brightness_level;
   g_async_queue_push (priv->brightness_queue, value);
 }
-
 static gboolean
-volume_beep (AdvancedBacklightPlugin * vsp)
+volume_beep (GtkWidget *w, GdkEventButton *e, AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
   g_debug ("%s\n", __PRETTY_FUNCTION__);
   if (priv->volume_beep)
     hildon_play_system_sound (DEFAULT_BEEP);
-  priv->timer_id = 0;
-  return FALSE;                 /* One shot */
+  //priv->timer_id = 0;
+  return FALSE;
 }
-
 static void
 advanced_backlight_plugin_update_volume_value (AdvancedBacklightPlugin * vsp, gint volume)
 {
@@ -780,7 +779,7 @@ advanced_backlight_plugin_update_volume_value (AdvancedBacklightPlugin * vsp, gi
   gconf_client_set_int (priv->gconf_client, GCONF_MASTER_VOLUME, volume, NULL);
   g_debug ("%s ->\n", __PRETTY_FUNCTION__);
 }
-
+/*
 static gpointer
 advanced_backlight_plugin_update_volume_thread (gpointer d)
 {
@@ -816,7 +815,7 @@ advanced_backlight_plugin_update_volume_thread (gpointer d)
     }
   return g_thread_self ();
 }
-
+*/
 /*
  Update the system-volume according to the volumebar level
  */
@@ -825,7 +824,7 @@ advanced_backlight_plugin_update_volume (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
   gint volume;
-  int *value;
+  //int *value;
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
@@ -838,23 +837,26 @@ advanced_backlight_plugin_update_volume (AdvancedBacklightPlugin * vsp)
   priv->volume_level = volume;
   advanced_backlight_plugin_update_icons (vsp);
 
-  value = g_new (int, 1);
-  *value = volume;
-  g_async_queue_push (priv->volume_queue, value);
+  //value = g_new (int, 1);
+  //*value = volume;
+  //g_async_queue_push (priv->volume_queue, value);
+  advanced_backlight_plugin_update_volume_value(vsp, volume);
 }
 
 static void
 volume_level_changed (GtkWidget * widget, AdvancedBacklightPlugin * vsp)
 {
-  AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
+  //AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
   advanced_backlight_plugin_update_volume (vsp);
   g_debug ("%s\n", __PRETTY_FUNCTION__);
   /* We only want to beep on changes with the slider */
+  /*
   if (priv->timer_id > 0)
     {
       g_source_remove (priv->timer_id);
     }
   priv->timer_id = g_timeout_add (VOLUME_BEEP_DELAY, (GSourceFunc) volume_beep, vsp);
+  */
 }
 
 static void
@@ -888,7 +890,7 @@ advanced_backlight_plugin_update_volume_fields (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
   gint volume = gconf_client_get_int (priv->gconf_client, GCONF_MASTER_VOLUME, NULL);
-  priv->mute = (volume < 0);
+  priv->mute = (volume < 0 || (volume == 0 && priv->mute));
   priv->volume_level = (priv->mute ? -1 : 1) * volume;
 }
 
@@ -950,7 +952,7 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   priv->brightness_slider = hildon_hvolumebar_new ();
   gtk_container_forall (GTK_CONTAINER (priv->brightness_slider), (GtkCallback) get_brightness_scale, vsp);
   gtk_range_set_increments (GTK_RANGE (priv->brightness_scale), 1, 1);
-  gtk_range_set_range (GTK_RANGE (priv->brightness_scale), priv->allow_zero ? 0 : 1, priv->max_brightness);
+  gtk_range_set_range (GTK_RANGE (priv->brightness_scale), (priv->allow_zero && !priv->is_770) ? 0 : 1, priv->max_brightness);
   gtk_range_set_update_policy (GTK_RANGE (priv->brightness_scale), GTK_UPDATE_DELAYED);
   hildon_volumebar_set_level (HILDON_VOLUMEBAR (priv->brightness_slider), priv->brightness_level);
   g_object_set (G_OBJECT (priv->brightness_slider), "has_mute", FALSE, NULL);
@@ -963,6 +965,8 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   hildon_volumebar_set_level (HILDON_VOLUMEBAR (priv->volume_slider), priv->volume_level);
   g_signal_connect (G_OBJECT (priv->volume_slider), "level-changed", G_CALLBACK (volume_level_changed), vsp);
   g_signal_connect (G_OBJECT (priv->volume_slider), "mute-toggled", G_CALLBACK (volume_mute_toggled), vsp);
+  gtk_widget_add_events(GTK_WIDGET(priv->volume_scale), GDK_BUTTON_RELEASE_MASK);
+  g_signal_connect(G_OBJECT(priv->volume_scale), "button-release-event", G_CALLBACK(volume_beep), vsp);
 
 
   /* Create rotation buttons with rotated labels */
@@ -1571,7 +1575,8 @@ advanced_backlight_plugin_configure_applet (AdvancedBacklightPlugin * vsp)
   gtk_box_pack_start (GTK_BOX (vbox), brightness_caption, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), volume_caption, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), volume_beep_caption, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), allow_zero_caption, FALSE, FALSE, 0);
+  if (!priv->is_770)
+    gtk_box_pack_start (GTK_BOX (vbox), allow_zero_caption, FALSE, FALSE, 0);
 
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
@@ -1580,7 +1585,10 @@ advanced_backlight_plugin_configure_applet (AdvancedBacklightPlugin * vsp)
 
   if (response == GTK_RESPONSE_ACCEPT)
     {
-      priv->allow_zero = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (allow_zero_checkbox));
+      if (!priv->is_770)
+        priv->allow_zero = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (allow_zero_checkbox));
+      else
+	priv->allow_zero = 0;
       if (!priv->is_n810 && priv->allow_zero)
         {
           confirmation_dialog =
